@@ -51,13 +51,15 @@ class GitIssuePublisher(Publisher):
         """
         try:
             title = f"Automated Issue on branch {self.branch}"
-
+            print(1)
             existing_issue = self.get_thread(title)
 
             # main_comment = existing_issue.get_comments()[0]
-            updated_body = self.append_data_to_comment(existing_issue.body, data['message']['adherence'])
+            print(2)
+            updated_body = self.append_data_to_comment(existing_issue.body or '', data['message']['adherence'])
+            print(3)
             existing_issue.edit(body=updated_body)
-
+            print(4)
             existing_issue.create_comment(self.generate_report(data))
 
             return 
